@@ -1,6 +1,4 @@
 /*
- * $Id: shoutcast.c,v 1.141.2.3 2004/08/06 00:36:30 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -34,7 +32,7 @@
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "streamtuner.h"
 #include "art/shoutcast.h"
 
@@ -97,6 +95,8 @@ typedef struct
 
 /*** variable declarations ***************************************************/
 
+static STHandler *handler = NULL;
+
 static regex_t re_header_charset;
 static regex_t re_body_charset;
 static regex_t re_genre;
@@ -537,7 +537,7 @@ reload_page (const char *url, ReloadInfo *info, GError **err)
     {
       stream_free_cb(info->stream, NULL);
       if (status) /* only display warning if the transfer was otherwise correct */
-	st_notice(_("SHOUTcast:EOF: found unterminated stream"));
+	st_handler_notice(handler, _("EOF: found unterminated stream"));
     }
 
   if (! status)
@@ -602,8 +602,8 @@ reload_body_cb (const char *line, gpointer data)
 	line = converted;
       else
 	{
-	  st_notice(_("SHOUTcast: unable to convert line to UTF-8: %s"),
-		    convert_err->message);
+	  st_handler_notice(handler, _("unable to convert line to UTF-8 encoding: %s"),
+			    convert_err->message);
 	  
 	  g_error_free(convert_err);
 	  return;
@@ -617,7 +617,7 @@ reload_body_cb (const char *line, gpointer data)
     {
       if (info->stream)	/* a malformed stream remains, free it */
 	{
-	  st_notice(_("SHOUTcast: found unterminated stream"));
+	  st_handler_notice(handler, _("found unterminated stream"));
 	  stream_free_cb(info->stream, NULL);
 	}
 	  
@@ -642,7 +642,7 @@ reload_body_cb (const char *line, gpointer data)
 	    }
 	  else
 	    {
-	      st_notice(_("SHOUTcast: found incomplete stream"));
+	      st_handler_notice(handler, _("found incomplete stream"));
 	      stream_free_cb(info->stream, NULL);
 	    }
 
@@ -650,7 +650,7 @@ reload_body_cb (const char *line, gpointer data)
 	}
       else
 	{
-	  st_notice(_("SHOUTcast: found misplaced bitrate"));
+	  st_handler_notice(handler, _("found misplaced bitrate"));
 	  g_free(sub1);
 	}
     }
@@ -684,7 +684,7 @@ reload_body_cb (const char *line, gpointer data)
 	    }
 	  else
 	    {
-	      st_notice(_("SHOUTcast: parent category not found"));
+	      st_handler_notice(handler, _("parent category not found"));
 	      st_category_free(category);
 	      g_node_destroy(node);
 	    }
@@ -705,7 +705,7 @@ reload_body_cb (const char *line, gpointer data)
 	}
       else
 	{
-	  st_notice(_("SHOUTcast: found misplaced genre, homepage and description"));
+	  st_handler_notice(handler, _("found misplaced genre, homepage and description"));
 	  g_free(sub1);
 	  g_free(sub2);
 	  g_free(sub3);
@@ -717,7 +717,7 @@ reload_body_cb (const char *line, gpointer data)
 	info->stream->now_playing = sub1;
       else
 	{
-	  st_notice(_("SHOUTcast: found misplaced now_playing"));
+	  st_handler_notice(handler, _("found misplaced now_playing"));
 	  g_free(sub1);
 	}
     }
@@ -730,7 +730,7 @@ reload_body_cb (const char *line, gpointer data)
 	}
       else
 	{
-	  st_notice(_("SHOUTcast: found misplaced listeners and max"));
+	  st_handler_notice(handler, _("found misplaced listeners and max"));
 	  g_free(sub1);
 	  g_free(sub2);
 	}
@@ -804,8 +804,6 @@ init_re (void)
 static void
 init_handler (void)
 {
-  STHandler *handler;
-  
   GNode *stock_categories;
   STCategory *category;
 
@@ -889,17 +887,12 @@ init_handler (void)
   st_handlers_add(handler);
 }
 
-#ifdef WITH_STATIC_SHOUTCAST
-gboolean
-shoutcast_init (GError **err)
-#else
 gboolean
 plugin_init (GError **err)
-#endif
 {
   gboolean status;
   
-  if (! st_check_api_version(5, 6))
+  if (! st_check_api_version(5, 7))
     {
       g_set_error(err, 0, 0, _("API version mismatch"));
       return FALSE;
