@@ -1,6 +1,4 @@
 /*
- * $Id: sg-dumper.c,v 1.12.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -37,7 +35,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "sg-dumper.h"
 
 /*** function declarations ***************************************************/
@@ -47,7 +45,7 @@ static gboolean sg_dumper_write_indent	(SGDumper	*dumper,
 static gboolean sg_dumper_printf	(SGDumper	*dumper,
 					 GError		**err,
 					 const char	*format,
-					 ...);
+					 ...) G_GNUC_PRINTF(3, 4);
 static gboolean sg_dumper_write_str	(SGDumper	*dumper,
 					 const char	*str,
 					 GError		**err);
