@@ -1,6 +1,4 @@
 /*
- * $Id: sg-util.h,v 1.19.2.3 2004/08/05 13:37:40 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -60,9 +58,14 @@ void		sg_string_append_escaped	(GString	*string,
 						 const char	*str);
 void		sg_string_append_printf_escaped	(GString	*string,
 						 const char	*format,
-						 ...);
+						 ...) G_GNUC_PRINTF(2, 3);
 void		sg_string_append_vprintf_escaped (GString	*string,
 						  const char	*format,
 						  va_list	args);
+void		sg_object_link_int		(GObject	*object,
+						 const char	*property_name,
+						 int		*var);
+gboolean	sg_str_slist_contains		(GSList		*list,
+						 const char	*str);
 
 #endif /* _SG_UTIL_H */
