@@ -1,6 +1,4 @@
 /*
- * $Id: sgtk-auth-dialog.c,v 1.24.2.7 2004/08/05 13:37:40 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,9 +30,9 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <stdarg.h>
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "sgtk-hig.h"
@@ -143,23 +141,14 @@ sgtk_auth_dialog_init (sGtkAuthDialog *dialog)
   gtk_misc_set_alignment(GTK_MISC(password_label), 0, 0.5);
   gtk_entry_set_visibility(GTK_ENTRY(dialog->priv->password_entry), FALSE);
 
-  g_signal_connect(G_OBJECT(dialog->priv->name_entry),
-		   "changed",
-		   G_CALLBACK(sgtk_auth_dialog_entry_changed_h),
-		   dialog);
-  g_signal_connect(G_OBJECT(dialog->priv->password_entry),
-		   "changed",
-		   G_CALLBACK(sgtk_auth_dialog_entry_changed_h),
-		   dialog);
-
-  g_signal_connect(G_OBJECT(dialog->priv->name_entry),
-		   "activate",
-		   G_CALLBACK(sgtk_auth_dialog_entry_activate_h),
-		   dialog->priv->password_entry);
-  g_signal_connect(G_OBJECT(dialog->priv->password_entry),
-		   "activate",
-		   G_CALLBACK(sgtk_auth_dialog_entry_activate_h),
-		   dialog->priv->name_entry);
+  g_object_connect(dialog->priv->name_entry,
+		   "signal::changed", sgtk_auth_dialog_entry_changed_h, dialog,
+		   "signal::activate", sgtk_auth_dialog_entry_activate_h, dialog->priv->password_entry,
+		   NULL);
+  g_object_connect(dialog->priv->password_entry,
+		   "signal::changed", sgtk_auth_dialog_entry_changed_h, dialog,
+		   "signal::activate", sgtk_auth_dialog_entry_activate_h, dialog->priv->name_entry,
+		   NULL);
 
   table = gtk_table_new(3, 2, FALSE);
 
