@@ -1,6 +1,4 @@
 /*
- * $Id: sgtk-find-dialog.c,v 1.1.2.5 2004/08/05 16:54:03 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -31,7 +29,8 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "gettext.h"
+#include "config.h"
+#include <glib/gi18n.h>
 #include "sg-util.h"
 #include "sgtk-find-dialog.h"
 #include "sgtk-util.h"
@@ -211,10 +210,10 @@ sgtk_find_dialog_init (sGtkFindDialog *dialog)
   gtk_container_add(GTK_CONTAINER(SGTK_DIALOG(dialog)->contents), vbox);
   gtk_widget_show_all(vbox);
 
-  g_signal_connect(G_OBJECT(ENTRY(dialog)), "changed", G_CALLBACK(sgtk_find_dialog_entry_changed_h), dialog);
-  g_signal_connect(G_OBJECT(dialog->priv->case_sensitive), "toggled", G_CALLBACK(sgtk_find_dialog_case_sensitive_toggled_h), dialog);
-  g_signal_connect(G_OBJECT(dialog->priv->wrap_around), "toggled", G_CALLBACK(sgtk_find_dialog_wrap_around_toggled_h), dialog);
-  g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(sgtk_find_dialog_response_h), NULL);
+  g_signal_connect(ENTRY(dialog), "changed", G_CALLBACK(sgtk_find_dialog_entry_changed_h), dialog);
+  g_signal_connect(dialog->priv->case_sensitive, "toggled", G_CALLBACK(sgtk_find_dialog_case_sensitive_toggled_h), dialog);
+  g_signal_connect(dialog->priv->wrap_around, "toggled", G_CALLBACK(sgtk_find_dialog_wrap_around_toggled_h), dialog);
+  g_signal_connect(dialog, "response", G_CALLBACK(sgtk_find_dialog_response_h), NULL);
 }
 
 static void
