@@ -1,6 +1,4 @@
 /*
- * $Id: sgtk-stock.c,v 1.1.2.2 2004/08/06 18:45:27 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,8 +30,8 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-stock.h"
 
 /*** constant definitions ****************************************************/
