@@ -1,6 +1,4 @@
 /*
- * $Id: sgtk-util.h,v 1.13.2.4 2004/08/09 12:35:57 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -55,6 +53,8 @@ GdkPixbuf	*sgtk_pixbuf_scale		(GdkPixbuf	*pixbuf,
 						 GtkIconSize	size);
 void		sgtk_widget_set_next_widget	(GtkWidget	*widget,
 						 GtkWidget	*next);
+void		sgtk_widget_set_popup_menu	(GtkWidget	*widget,
+						 GtkMenu	*menu);
 void		sgtk_tree_model_make_countable	(GtkTreeModel	*model);
 gboolean	sgtk_tree_model_is_countable	(GtkTreeModel	*model);
 unsigned int	sgtk_tree_model_get_count	(GtkTreeModel	*model);
@@ -70,5 +70,8 @@ void		sgtk_accel_map_add_entry	(const char	*accel_path,
 gboolean	sgtk_accel_map_change_entry	(const char	*accel_path,
 						 const char	*accelerator,
 						 gboolean	replace);
+void		sgtk_window_link_size		(GtkWindow	*window,
+						 int		*width,
+						 int		*height);
 
 #endif /* _SGTK_UTIL_H */
