@@ -1,6 +1,4 @@
 /*
- * $Id: st-action.c,v 1.12.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,7 +31,7 @@
 
 #include "config.h"
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "sg-util.h"
 #include "st-thread.h"
 #include "st-action.h"
