@@ -1,6 +1,4 @@
 /*
- * $Id: st-bookmarks.c,v 1.30.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,8 +30,9 @@
  */
 
 #include "config.h"
+#include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "art/bookmarks.h"
 #include "sg-util.h"
 #include "sgtk-util.h"
