@@ -1,6 +1,4 @@
 /*
- * $Id: st-browser-tab-label.c,v 1.8.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,12 +30,13 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-blinking-image.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
 #include "st-browser-tab-label.h"
+#include "st-stock.h"
 
 /*** cpp *********************************************************************/
 
@@ -47,14 +46,16 @@
 
 enum {
   PROP_0,
-  PROP_TAB,
-  PROP_USE_EVENT_BOX
+  PROP_TAB
 };
 
 struct _STBrowserTabLabelPrivate
 {
-  gboolean	use_event_box;
   GtkWidget	*image;
+  GtkWidget	*menu;
+  GtkWidget	*stop_item;
+  GtkWidget	*reload_item;
+  GtkWidget	*visit_directory_homepage_item;
 };
 
 /*** variable declarations ***************************************************/
@@ -75,6 +76,13 @@ static void st_browser_tab_label_set_property (GObject *object,
 					       const GValue *value,
 					       GParamSpec *pspec);
 
+static void st_browser_tab_label_stop_activate_h (GtkMenuItem *menuitem,
+						  gpointer user_data);
+static void st_browser_tab_label_reload_activate_h (GtkMenuItem *menuitem,
+						    gpointer user_data);
+static void st_browser_tab_label_visit_directory_homepage_activate_h (GtkMenuItem *menuitem,
+								      gpointer user_data);
+
 /*** implementation **********************************************************/
 
 GType
@@ -123,13 +131,6 @@ st_browser_tab_label_class_init (STBrowserTabLabelClass *class)
 						      _("The tab label's STBrowserTab object"),
 						      ST_TYPE_BROWSER_TAB,
 						      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-  g_object_class_install_property(object_class,
-				  PROP_USE_EVENT_BOX,
-				  g_param_spec_boolean("use-event-box",
-						       _("Use Event Box"),
-						       _("Whether the tab label should use a GtkEventBox or not"),
-						       FALSE,
-						       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
@@ -143,6 +144,7 @@ st_browser_tab_label_finalize (GObject *object)
 {
   STBrowserTabLabel *tab_label = ST_BROWSER_TAB_LABEL(object);
 
+  gtk_widget_destroy(tab_label->priv->menu);
   g_free(tab_label->priv);
   
   G_OBJECT_CLASS(parent_class)->finalize(object);
@@ -156,8 +158,10 @@ st_browser_tab_label_constructor (GType type,
   GObject *object;
   STBrowserTabLabel *tab_label;
   GtkWidget *label;
+  GtkWidget *event_box;
   GtkWidget *hbox;
   GdkPixbuf *pixbuf;
+  GtkWidget *separator_item;
 
   object = G_OBJECT_CLASS(parent_class)->constructor(type,
 						     n_construct_properties,
@@ -167,21 +171,14 @@ st_browser_tab_label_constructor (GType type,
 
   /* event box */
 
-  if (tab_label->priv->use_event_box)
-    {
-      GtkWidget *event_box;
+  event_box = gtk_event_box_new();
+  hbox = gtk_hbox_new(FALSE, BOX_SPACING);
 
-      event_box = gtk_event_box_new();
-      hbox = gtk_hbox_new(FALSE, BOX_SPACING);
+  gtk_container_add(GTK_CONTAINER(tab_label), event_box);
+  gtk_container_add(GTK_CONTAINER(event_box), hbox);
 
-      gtk_container_add(GTK_CONTAINER(tab_label), event_box);
-      gtk_container_add(GTK_CONTAINER(event_box), hbox);
-
-      gtk_widget_show(event_box);
-      gtk_widget_show(hbox);
-    }
-  else
-    hbox = GTK_WIDGET(tab_label);
+  gtk_widget_show(event_box);
+  gtk_widget_show(hbox);
 
   /* image */
 
@@ -211,9 +208,66 @@ st_browser_tab_label_constructor (GType type,
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
+  /* popup menu */
+
+  tab_label->priv->menu = gtk_menu_new();
+
+  tab_label->priv->stop_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_STOP, NULL);
+  tab_label->priv->reload_item = gtk_image_menu_item_new_from_stock(ST_STOCK_RELOAD, NULL);
+  tab_label->priv->visit_directory_homepage_item = gtk_image_menu_item_new_from_stock(ST_STOCK_VISIT_DIRECTORY_HOMEPAGE, NULL);
+
+  g_signal_connect(tab_label->priv->stop_item, "activate", G_CALLBACK(st_browser_tab_label_stop_activate_h), tab_label);
+  g_signal_connect(tab_label->priv->reload_item, "activate", G_CALLBACK(st_browser_tab_label_reload_activate_h), tab_label);
+  g_signal_connect(tab_label->priv->visit_directory_homepage_item, "activate", G_CALLBACK(st_browser_tab_label_visit_directory_homepage_activate_h), tab_label);
+
+  gtk_widget_show(tab_label->priv->stop_item);
+  gtk_widget_show(tab_label->priv->reload_item);
+  gtk_widget_show(tab_label->priv->visit_directory_homepage_item);
+
+  /* initialize sensitivity */
+
+  gtk_widget_set_sensitive(tab_label->priv->stop_item, st_browser_tab_can_stop(tab_label->tab));
+  gtk_widget_set_sensitive(tab_label->priv->reload_item, st_browser_tab_can_reload(tab_label->tab));
+  gtk_widget_set_sensitive(tab_label->priv->visit_directory_homepage_item, st_browser_tab_can_visit_homepage(tab_label->tab));
+
+  gtk_menu_shell_append(GTK_MENU_SHELL(tab_label->priv->menu), tab_label->priv->stop_item);
+  gtk_menu_shell_append(GTK_MENU_SHELL(tab_label->priv->menu), tab_label->priv->reload_item);
+
+  separator_item = gtk_separator_menu_item_new();
+  gtk_widget_show(separator_item);
+  gtk_menu_shell_append(GTK_MENU_SHELL(tab_label->priv->menu), separator_item);
+
+  gtk_menu_shell_append(GTK_MENU_SHELL(tab_label->priv->menu), tab_label->priv->visit_directory_homepage_item);
+
+  sgtk_widget_set_popup_menu(event_box, GTK_MENU(tab_label->priv->menu));
+
   return object;
 }
 
+static void
+st_browser_tab_label_stop_activate_h (GtkMenuItem *menuitem,
+				      gpointer user_data)
+{
+  STBrowserTabLabel *tab_label = user_data;
+  st_browser_tab_stop(tab_label->tab);
+}
+
+static void
+st_browser_tab_label_reload_activate_h (GtkMenuItem *menuitem,
+					gpointer user_data)
+{
+  STBrowserTabLabel *tab_label = user_data;
+  st_browser_tab_reload(tab_label->tab);
+}
+
+static void
+st_browser_tab_label_visit_directory_homepage_activate_h (GtkMenuItem *menuitem,
+							  gpointer user_data)
+{
+  STBrowserTabLabel *tab_label = user_data;
+  st_browser_tab_visit_homepage(tab_label->tab);
+}
+
 static void
 st_browser_tab_label_set_property (GObject *object,
 				   unsigned int prop_id,
@@ -228,10 +282,6 @@ st_browser_tab_label_set_property (GObject *object,
       tab_label->tab = g_value_get_object(value);
       break;
 
-    case PROP_USE_EVENT_BOX:
-      tab_label->priv->use_event_box = g_value_get_boolean(value);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
       break;
@@ -239,23 +289,24 @@ st_browser_tab_label_set_property (GObject *object,
 }
 
 GtkWidget *
-st_browser_tab_label_new (STBrowserTab *tab, gboolean use_event_box)
+st_browser_tab_label_new (STBrowserTab *tab)
 {
   return g_object_new(ST_TYPE_BROWSER_TAB_LABEL,
 		      "spacing", BOX_SPACING,
 		      "tab", tab,
-		      "use-event-box", use_event_box,
 		      NULL);
 }
 
 void
-st_browser_tab_label_set_blinking (STBrowserTabLabel *tab_label,
-				   gboolean blinking)
+st_browser_tab_label_set_reloading (STBrowserTabLabel *tab_label,
+				    gboolean reloading)
 {
   g_return_if_fail(ST_IS_BROWSER_TAB_LABEL(tab_label));
 
   if (tab_label->priv->image)
-    sgtk_blinking_image_set_blinking(SGTK_BLINKING_IMAGE(tab_label->priv->image), blinking);
+    sgtk_blinking_image_set_blinking(SGTK_BLINKING_IMAGE(tab_label->priv->image), reloading);
+
+  gtk_widget_set_sensitive(tab_label->priv->stop_item, reloading);
 }
 
 void
