@@ -1,6 +1,4 @@
 /*
- * $Id: st-browser-tab-label.h,v 1.4 2004/03/18 15:33:26 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -61,10 +59,9 @@ typedef struct
   
 GType st_browser_tab_label_get_type (void);
 
-GtkWidget *st_browser_tab_label_new		(STBrowserTab      *tab,
-						 gboolean          use_event_box);
-void      st_browser_tab_label_set_blinking	(STBrowserTabLabel *tab_label,
-						 gboolean          blinking);
+GtkWidget *st_browser_tab_label_new		(STBrowserTab      *tab);
+void      st_browser_tab_label_set_reloading	(STBrowserTabLabel *tab_label,
+						 gboolean          reloading);
 void      st_browser_tab_label_set_icon_visible	(STBrowserTabLabel *tab_label,
 						 gboolean          visible);
 
