@@ -1,6 +1,4 @@
 /*
- * $Id: st-browser-tab.c,v 1.141.2.7 2004/08/09 12:43:20 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,8 +31,8 @@
 
 #include "config.h"
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-util.h"
 #include "sg-util.h"
 #include "st-browser-tab.h"
@@ -48,6 +46,7 @@
 #include "st-settings.h"
 #include "st-category-store.h"
 #include "st-stream-store.h"
+#include "st-util.h"
 
 /*** type definitions ********************************************************/
 
@@ -72,7 +71,6 @@ typedef struct
 
 struct _STBrowserTabPrivate
 {
-  GSList	*labels;		/* a list of tab labels */
   STThread	*thread;
 
   unsigned int	context_counts;
@@ -98,7 +96,6 @@ static void st_browser_tab_set_property	(GObject	*object,
 					 const GValue	*value,
 					 GParamSpec	*pspec);
 static void st_browser_tab_finalize	(GObject	*object);
-static void st_browser_tab_unrealize	(GtkWidget	*widget);
 
 static void st_browser_tab_update_counters	(STBrowserTab    *tab);
 static void st_browser_tab_set_reloading	(STBrowserTab    *tab,
@@ -119,6 +116,10 @@ static void st_browser_tab_category_selection_changed_h (STCategoryView *view,
 static void st_browser_tab_set_streams (STBrowserTab *tab,
 					STStreamStore *streams);
 
+static void st_browser_tab_paned_notify_position_h	(GObject     *object,
+							 GParamSpec  *pspec,
+							 gpointer    user_data);
+
 /*** implementation **********************************************************/
 
 GType
@@ -153,7 +154,6 @@ static void
 st_browser_tab_class_init (STBrowserTabClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(class);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(class);
 
   parent_class = g_type_class_peek_parent(class);
 
@@ -161,8 +161,6 @@ st_browser_tab_class_init (STBrowserTabClass *class)
   object_class->set_property = st_browser_tab_set_property;
   object_class->finalize = st_browser_tab_finalize;
 
-  widget_class->unrealize = st_browser_tab_unrealize;
-
   g_object_class_install_property(object_class,
 				  PROP_HANDLER,
 				  g_param_spec_pointer("handler",
@@ -226,14 +224,10 @@ st_browser_tab_constructor (GType type,
 
       categories = st_handler_get_categories(tab->handler);
 
-      g_signal_connect_swapped(G_OBJECT(categories),
-			       "row-deleted",
-			       G_CALLBACK(st_browser_tab_update_counters),
-			       tab);
-      g_signal_connect_swapped(G_OBJECT(categories),
-			       "row-inserted",
-			       G_CALLBACK(st_browser_tab_update_counters),
-			       tab);
+      g_object_connect(categories,
+		       "swapped-signal::row-deleted", st_browser_tab_update_counters, tab,
+		       "swapped-signal::row-inserted", st_browser_tab_update_counters, tab,
+		       NULL);
 
       tab->category_view = (STCategoryView *) st_category_view_new(categories);
       g_object_unref(categories);
@@ -242,7 +236,7 @@ st_browser_tab_constructor (GType type,
       gtk_paned_add1(GTK_PANED(tab), scrolled);
       gtk_widget_show_all(scrolled);
 
-      g_signal_connect(G_OBJECT(tab->category_view),
+      g_signal_connect(tab->category_view,
 		       "selection-changed",
 		       G_CALLBACK(st_browser_tab_category_selection_changed_h),
 		       tab);
@@ -259,8 +253,16 @@ st_browser_tab_constructor (GType type,
   gtk_paned_add2(GTK_PANED(tab), scrolled);
   gtk_widget_show_all(scrolled);
 
+  tab->label = st_browser_tab_label_new(tab);
+  gtk_widget_show(tab->label);
+
   gtk_paned_set_position(GTK_PANED(tab), st_handler_get_paned_position(tab->handler));
 
+  g_signal_connect(tab,
+		   "notify::position",
+		   G_CALLBACK(st_browser_tab_paned_notify_position_h),
+		   NULL);
+
   return object;
 }
 
@@ -289,52 +291,12 @@ st_browser_tab_finalize (GObject *object)
 {
   STBrowserTab *tab = ST_BROWSER_TAB(object);
 
-  g_slist_free(tab->priv->labels);
   g_free(tab->priv);
   g_object_unref(tab->statusbar);
 
   G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
-static void
-st_browser_tab_unrealize (GtkWidget *widget)
-{
-  STBrowserTab *tab = ST_BROWSER_TAB(widget);
-
-  st_handler_set_paned_position(tab->handler, gtk_paned_get_position(GTK_PANED(tab)));
-
-  GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
-}
-
-GtkWidget *
-st_browser_tab_get_label (STBrowserTab *tab, gboolean use_event_box)
-{
-  GtkWidget *label;
-
-  g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), NULL);
-
-  /*
-   * A widget can't be shared by multiple containers, so we create a
-   * new label for every call of this function.
-   */
-
-  label = st_browser_tab_label_new(tab, use_event_box);
-  tab->priv->labels = g_slist_append(tab->priv->labels, label);
-
-  return label;
-}
-
-void
-st_browser_tab_set_label_icon_visible (STBrowserTab *tab, gboolean visible)
-{
-  GSList *l;
-
-  g_return_if_fail(ST_IS_BROWSER_TAB(tab));
-
-  SG_LIST_FOREACH(l, tab->priv->labels)
-    st_browser_tab_label_set_icon_visible(ST_BROWSER_TAB_LABEL(l->data), visible);
-}
-
 GtkWidget *
 st_browser_tab_new (STHandler *handler)
 {
@@ -351,6 +313,14 @@ st_browser_tab_update_sensitivity (STBrowserTab *tab)
   st_stream_view_update_sensitivity(tab->stream_view);
 }
 
+gboolean
+st_browser_tab_can_reload (STBrowserTab *tab)
+{
+  g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), FALSE);
+
+  return ST_HANDLER_EVENT_HAS_RELOAD(tab->handler);
+}
+
 void
 st_browser_tab_reload (STBrowserTab *tab)
 {
@@ -523,18 +493,31 @@ st_browser_tab_stop (STBrowserTab *tab)
   st_thread_abort(tab->priv->thread);
 }
 
+gboolean
+st_browser_tab_can_visit_homepage (STBrowserTab *tab)
+{
+  g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), FALSE);
+
+  return st_handler_get_home(tab->handler) != NULL;
+}
+
+void
+st_browser_tab_visit_homepage (STBrowserTab *tab)
+{
+  g_return_if_fail(ST_IS_BROWSER_TAB(tab));
+
+  st_visit_homepage(st_handler_get_home(tab->handler));
+}
+
 static void
 st_browser_tab_set_reloading (STBrowserTab *tab, gboolean reloading)
 {
-  GSList *l;
-
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
   tab->reloading = reloading;
 
   st_statusbar_set_active(ST_STATUSBAR(tab->statusbar), tab->reloading);
-  SG_LIST_FOREACH(l, tab->priv->labels)
-    st_browser_tab_label_set_blinking(ST_BROWSER_TAB_LABEL(l->data), tab->reloading);
+  st_browser_tab_label_set_reloading(ST_BROWSER_TAB_LABEL(tab->label), tab->reloading);
 
   g_signal_emit(tab, browser_tab_signals[RELOADING_CHANGED], 0, tab->reloading);
 }
@@ -624,16 +607,19 @@ st_browser_tab_set_streams (STBrowserTab *tab, STStreamStore *streams)
 
   st_stream_view_set_store(tab->stream_view, streams);
   if (streams)
-    {
-      g_signal_connect_swapped(G_OBJECT(streams),
-			       "row-deleted",
-			       G_CALLBACK(st_browser_tab_update_counters),
-			       tab);
-      g_signal_connect_swapped(G_OBJECT(streams),
-			       "row-inserted",
-			       G_CALLBACK(st_browser_tab_update_counters),
-			       tab);
-    }
+    g_object_connect(streams,
+		     "swapped-signal::row-deleted", st_browser_tab_update_counters, tab,
+		     "swapped-signal::row-inserted", st_browser_tab_update_counters, tab,
+		     NULL);
 
   st_browser_tab_update_counters(tab);
 }
+
+static void
+st_browser_tab_paned_notify_position_h (GObject *object,
+					GParamSpec *pspec,
+					gpointer user_data)
+{
+  st_handler_set_paned_position(ST_BROWSER_TAB(object)->handler,
+				gtk_paned_get_position(GTK_PANED(object)));
+}
