@@ -1,6 +1,4 @@
 /*
- * $Id: st-browser-tab.h,v 1.41.2.1 2004/08/06 00:36:30 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -62,6 +60,8 @@ typedef struct
 
   STCategoryView		*category_view;
   STStreamView			*stream_view;
+
+  GtkWidget			*label;
 } STBrowserTab;
 
 typedef struct
@@ -74,16 +74,15 @@ typedef struct
 
 GType		st_browser_tab_get_type		(void);
 GtkWidget	*st_browser_tab_new		(STHandler	*handler);
-GtkWidget	*st_browser_tab_get_label	(STBrowserTab	*tab,
-						 gboolean	use_event_box);
-void		st_browser_tab_set_label_icon_visible (STBrowserTab *tab,
-						       gboolean     visible);
 
 void		st_browser_tab_update_sensitivity (STBrowserTab	*tab);
 
+gboolean	st_browser_tab_can_reload	(STBrowserTab	*tab);
 void		st_browser_tab_reload		(STBrowserTab	*tab);
 void		st_browser_tab_update		(STBrowserTab	*tab);
 gboolean	st_browser_tab_can_stop		(STBrowserTab	*tab);
 void		st_browser_tab_stop		(STBrowserTab	*tab);
+gboolean	st_browser_tab_can_visit_homepage (STBrowserTab	*tab);
+void		st_browser_tab_visit_homepage	(STBrowserTab	*tab);
 
 #endif /* _ST_BROWSER_TAB_H */
