@@ -1,6 +1,4 @@
 /*
- * $Id: st-cache-load.c,v 1.60.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,8 +31,8 @@
 
 #include "config.h"
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-parser.h"
 #include "st-handler.h"
 #include "st-handlers.h"
