@@ -1,6 +1,4 @@
 /*
- * $Id: st-cache-save.c,v 1.46.2.2 2004/05/11 15:40:41 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -35,8 +33,8 @@
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-dumper.h"
 #include "st-handler.h"
 #include "st-handlers.h"
