@@ -1,6 +1,4 @@
 /*
- * $Id: st-config-load.c,v 1.35.2.5 2004/08/06 00:36:30 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -34,8 +32,8 @@
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
+#include <glib/gi18n.h>
 #include <glib-object.h>
-#include "gettext.h"
 #include "sg-parser.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
@@ -56,7 +54,7 @@ enum {
   STATEMENT_OPTIONS_TOOLBAR_THEME,		/* obsolete */
   STATEMENT_OPTIONS_TOOLBAR_STYLE,
   STATEMENT_OPTIONS_TOOLBAR_SIZE,
-  STATEMENT_OPTIONS_SAVE_AUTOMATIC,
+  STATEMENT_OPTIONS_SAVE_AUTOMATIC,		/* obsolete */
   STATEMENT_OPTIONS_MAIN_WINDOW_WIDTH,
   STATEMENT_OPTIONS_MAIN_WINDOW_HEIGHT,
   STATEMENT_OPTIONS_MAIN_WINDOW_DIVIDER,	/* deprecated */
@@ -85,6 +83,7 @@ enum {
   STATEMENT_OPTIONS_FIND_CASE_SENSITIVE,
   STATEMENT_OPTIONS_FIND_WRAP_AROUND,
   STATEMENT_OPTIONS_FIND_HISTORY,
+  STATEMENT_OPTIONS_MUSIC_DIR,
 
   STATEMENT_ACTION,
   STATEMENT_ACTION_COMMAND,
@@ -155,7 +154,7 @@ static SGParserDefinition config_definitions[] = {
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_TOOLBAR_SIZE,
     "toolbar_size",	FALSE,		G_TYPE_INT
   },
-  {
+  {				/* obsolete */
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_SAVE_AUTOMATIC,
     "save_automatic",	FALSE,		G_TYPE_BOOLEAN
   },
@@ -275,6 +274,10 @@ static SGParserDefinition config_definitions[] = {
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_HISTORY,
     "find_history",	TRUE,		G_TYPE_NONE
   }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_MUSIC_DIR,
+    "music_dir",	FALSE,		G_TYPE_STRING
+  }, 
   {
     0,			STATEMENT_ACTION,
     "action",		TRUE,		G_TYPE_STRING
@@ -412,10 +415,6 @@ st_config_load (const char *filename, GError **err)
 	      st_settings.toolbar_size = g_value_get_int(&info.statement->value);
 	      break;
 
-	    case STATEMENT_OPTIONS_SAVE_AUTOMATIC:
-	      st_settings.save_automatic = g_value_get_boolean(&info.statement->value);
-	      break;
-	      
 	    case STATEMENT_OPTIONS_WINDOW_WIDTH:	/* deprecated */
 	    case STATEMENT_OPTIONS_MAIN_WINDOW_WIDTH:
 	      st_settings.main_window_width = g_value_get_int(&info.statement->value);
@@ -519,6 +518,7 @@ st_config_load (const char *filename, GError **err)
 	    case STATEMENT_HANDLER_SELECTED_STREAM:
 	    case STATEMENT_HANDLER_EXPANDED_CATEGORIES:
 	    case STATEMENT_HANDLER_SELECTED_STREAMS:
+	    case STATEMENT_OPTIONS_SAVE_AUTOMATIC:
 	      sg_parser_warn(info.parser, _("obsolete statement, ignored"));
 	      break;
 
@@ -545,6 +545,11 @@ st_config_load (const char *filename, GError **err)
 	      st_settings.find_wrap_around = g_value_get_boolean(&info.statement->value);
 	      break;
 
+	    case STATEMENT_OPTIONS_MUSIC_DIR:
+	      g_free(st_settings.music_dir);
+	      st_settings.music_dir = g_value_dup_string(&info.statement->value);
+	      break;
+
 	    case STATEMENT_ACTION:
 	      info.action = g_value_dup_string(&info.statement->value);
 	      break;
