@@ -1,6 +1,4 @@
 /*
- * $Id: st-dialog-api.h,v 1.11 2004/03/21 20:58:17 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -37,27 +35,31 @@
 #include <glib.h>
 #include <stdarg.h>
 
-void	st_notice		(const char	*format, ...);
+void	st_notice		(const char	*format,
+				 ...) G_GNUC_PRINTF(1, 2);
 
 void	st_info_dialog		(const char	*primary,
 				 const char	*format,
-				 ...);
+				 ...) G_GNUC_PRINTF(2, 3);
 void	st_error_dialog		(const char	*primary,
 				 const char	*format,
-				 ...);
+				 ...) G_GNUC_PRINTF(2, 3);
 char	*st_search_dialog	(void);
 
 char	*st_dialog_normalize	(const char	*str);
 
 /* deprecated functions */
 
-void	st_warning		(const char	*format, ...);
-void	st_error		(const char	*format, ...);
-int	st_question		(const char	*format, ...);
+void	st_warning		(const char	*format,
+				 ...) G_GNUC_PRINTF(1, 2);
+void	st_error		(const char	*format,
+				 ...) G_GNUC_PRINTF(1, 2);
+int	st_question		(const char	*format,
+				 ...) G_GNUC_PRINTF(1, 2);
 
 char	*st_prompt		(gboolean	hidden,
 				 const char	*init,
 				 const char	*format,
-				 ...);
+				 ...) G_GNUC_PRINTF(3, 4);
 
 #endif /* _ST_DIALOG_API_H */
