@@ -1,6 +1,4 @@
 /*
- * $Id: st-dialog.c,v 1.30 2004/03/21 20:58:18 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -171,21 +169,28 @@ st_search_dialog (void)
   return str;
 }
 
-/*
- * Calls sg_str_sentencize() on STR, then changes all occurrences of
- * ": Xy" and "(Xy" to ": xy" and "(xy".
- *
- * Meant to be used as a pretty-printer for secondary strings.
- */
 char *
 st_dialog_normalize (const char *str)
 {
-  char *normalized;
+  char *copy;
   int i;
+  char *normalized;
   gboolean attn1 = FALSE;
   gboolean attn2 = FALSE;
 
-  normalized = sg_str_sentencize(str);
+  g_return_val_if_fail(str != NULL, NULL);
+
+  copy = g_strdup(str);
+
+  /* remove trailing newline(s) */
+  for (i = strlen(copy) - 1; i >= 0; i--)
+    if (copy[i] == '\n')
+      copy[i] = 0;
+    else
+      break;
+
+  normalized = sg_str_sentencize(copy);
+  g_free(copy);
 
   for (i = 0; normalized[i]; i++)
     {
