@@ -1,6 +1,4 @@
 /*
- * $Id: st-handler.c,v 1.124.2.3 2004/08/06 00:36:30 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,8 +31,8 @@
 
 #include "config.h"
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "st-category-bag.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
@@ -42,6 +40,7 @@
 #include "st-stream-bag.h"
 #include "st-category-store.h"
 #include "st-stream-store.h"
+#include "st-dialog-api.h"
 
 /*** type definitions ********************************************************/
 
@@ -385,6 +384,23 @@ st_handler_bind (STHandler *handler,
   handler->priv->callbacks[event].data = data;
 }
 
+void
+st_handler_notice (STHandler *handler, const char *format, ...)
+{
+  va_list args;
+  char *notice;
+
+  g_return_if_fail(ST_IS_HANDLER(handler));
+  g_return_if_fail(format != NULL);
+
+  va_start(args, format);
+  notice = g_strdup_vprintf(format, args);
+  va_end(args);
+
+  st_notice("%s: %s", handler->priv->label, notice);
+  g_free(notice);
+}
+
 /*** private implementation **************************************************/
 
 static void
