@@ -1,6 +1,4 @@
 /*
- * $Id: st-link.c,v 1.11.2.4 2004/08/05 13:48:27 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,8 +30,8 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-util.h"
 #include "st-link.h"
 #include "st-action.h"
@@ -154,25 +152,21 @@ st_link_init (STLink *link)
   gtk_item_factory_create_items(link->priv->factory, G_N_ELEMENTS(entries), entries, NULL);
 
   item = gtk_item_factory_get_item(link->priv->factory, N_("/Open Link"));
-  g_signal_connect(G_OBJECT(item), "activate",
-		   G_CALLBACK(st_link_open_activate_h), link);
+  g_signal_connect(item, "activate", G_CALLBACK(st_link_open_activate_h), link);
 
   item = gtk_item_factory_get_item(link->priv->factory, N_("/Copy Link Address"));
-  g_signal_connect(G_OBJECT(item), "activate",
-		   G_CALLBACK(st_link_copy_address_activate_h), link);
+  g_signal_connect(item, "activate", G_CALLBACK(st_link_copy_address_activate_h), link);
 
   link->priv->label = gtk_label_new(NULL);
   gtk_container_add(GTK_CONTAINER(link), link->priv->label);
   gtk_widget_show(link->priv->label);
 
-  g_signal_connect(G_OBJECT(link), "enter-notify-event",
-		   G_CALLBACK(st_link_enter_notify_event_h), NULL);
-  g_signal_connect(G_OBJECT(link), "leave-notify-event",
-		   G_CALLBACK(st_link_leave_notify_event_h), NULL);
-  g_signal_connect(G_OBJECT(link), "button-press-event",
-		   G_CALLBACK(st_link_button_press_event_h), NULL);
-  g_signal_connect(G_OBJECT(link), "button-release-event",
-		   G_CALLBACK(st_link_button_release_event_h), NULL);
+  g_object_connect(link,
+		   "signal::enter-notify-event", st_link_enter_notify_event_h, NULL,
+		   "signal::leave-notify-event", st_link_leave_notify_event_h, NULL,
+		   "signal::button-press-event", st_link_button_press_event_h, NULL,
+		   "signal::button-release-event", st_link_button_release_event_h, NULL,
+		   NULL);
 }
 
 static void
