@@ -1,6 +1,4 @@
 /*
- * $Id: st-m3u.c,v 1.8.2.2 2004/05/11 15:40:42 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -35,7 +33,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "sg-util.h"
 
 /*** function declarations ***************************************************/
