@@ -1,6 +1,4 @@
 /*
- * $Id: st-main.c,v 1.10.2.4 2004/08/05 13:01:50 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -34,8 +32,9 @@
 #include "config.h"
 #include <stdlib.h>
 #include <unistd.h>
+#include <errno.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-message-dialog.h"
 #include "sgtk-stock.h"
@@ -52,12 +51,15 @@
 #include "st-shell.h"
 #include "st-splash.h"
 #include "st-util.h"
+#include "st-dialog-api.h"
 
 /*** variable declarations ***************************************************/
 
 static char *custom_private_dir = NULL;
 static STShell *shell = NULL;
 
+static char **global_argv;
+
 /*** function declarations ***************************************************/
 
 static STSplash   *st_main_splash_create	(void);
@@ -66,6 +68,7 @@ static void       st_main_splash_set_text	(STSplash	*splash,
 static void       st_main_splash_set_progress	(STSplash	*splash,
 						 double		progress);
 
+static void       st_main_quit_real		(gboolean	restart);
 static void       st_main_parse_args		(int		argc,
 						 char		**argv);
 static void       st_main_print_help		(void);
@@ -181,33 +184,18 @@ st_main_get_transient (void)
 void
 st_main_quit (void)
 {
-  gboolean save = st_settings.save_automatic;
-  
-  if (! save)
-    {
-      GtkWidget *dialog;
-      GtkWidget *yes;
-      int response;
-      
-      dialog = sgtk_message_dialog_new(st_main_get_transient(),
-				       GTK_STOCK_DIALOG_WARNING,
-				       _("Save session before quitting?"),
-				       _("If you quit without saving, changes to your session will be discarded."));
-				       
-      gtk_dialog_add_button(GTK_DIALOG(dialog), ST_STOCK_QUIT_WITHOUT_SAVING, GTK_RESPONSE_NO);
-      gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-      yes = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_SAVE, GTK_RESPONSE_YES);
+  st_main_quit_real(FALSE);
+}
 
-      gtk_window_set_default(GTK_WINDOW(dialog), yes);
+void
+st_main_restart (void)
+{
+  st_main_quit_real(TRUE);
+}
 
-      response = gtk_dialog_run(GTK_DIALOG(dialog));
-      gtk_widget_destroy(dialog);
-
-      if (response == GTK_RESPONSE_CANCEL)
-	return;
-      save = response == GTK_RESPONSE_YES;
-    }
-  
+static void
+st_main_quit_real (gboolean restart)
+{
   /*
    * HIG 2.0:
    *
@@ -222,21 +210,40 @@ st_main_quit (void)
    */
 
   st_shell_prepare_finalize(shell);
-
-  if (save)
-    st_session_save();
+  st_session_save();
 
   st_shell_hide(shell);
   g_object_unref(shell);
 
+  if (restart)
+    {
+      char *secondary;
+      char *normalized;
+
+      execvp(global_argv[0], global_argv);
+
+      secondary = g_strdup_printf(_("Unable to restart streamtuner: %s"), g_strerror(errno));
+      normalized = st_dialog_normalize(secondary);
+      g_free(secondary);
+
+      st_error_dialog(_("A fatal error has occurred"), "%s", normalized);
+      g_free(normalized);
+    }
+
   gtk_main_quit();
 }
 
 static void
 st_main_parse_args (int argc, char **argv)
 {
+  int i;
   int c;
 
+  global_argv = g_new0(char *, argc + 1);
+  for (i = 0; i < argc; i++)
+    global_argv[i] = g_strdup(argv[i]);
+  global_argv[i] = NULL;
+
   while ((c = getopt(argc, argv, "d:thv")) != -1)
     switch (c)
       {
@@ -272,9 +279,4 @@ st_main_print_version (void)
 {
   g_print(_("%s version %s\n"), PACKAGE, VERSION);
   g_print(ST_COPYRIGHT "\n");
-
-#ifdef WITH_STATIC_SHOUTCAST
-  g_print("\n");
-  g_print(_("The SHOUTcast plugin has been built into streamtuner.\n"));
-#endif	/* WITH_STATIC_SHOUTCAST */
 }
