@@ -1,6 +1,4 @@
 /*
- * $Id: st-plugin.c,v 1.10.2.2 2004/05/11 15:40:42 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,14 +31,13 @@
 
 #include "config.h"
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gmodule.h>
-#include "gettext.h"
 #include "st-plugin.h"
 #include "st-plugins.h"
 
 /*** variable declarations ***************************************************/
 
-/* FIXME: ugly, remove it when we'll change st_handlers_add() */
 const char *st_plugin_current = NULL;	/* plugin being loaded */
 
 /*** implementation **********************************************************/
@@ -77,7 +74,7 @@ st_plugin_load (const char *filename, GError **err)
       g_error_free(tmp_err);
       return FALSE;
     }
-  st_plugins_list = g_slist_append(st_plugins_list, g_strdup(filename));
+  st_plugins_loaded_list = g_slist_append(st_plugins_loaded_list, g_strdup(filename));
 
   return TRUE;
 }
