@@ -1,6 +1,4 @@
 /*
- * $Id: st-preferences-dialog.c,v 1.22.2.2 2004/05/11 15:40:42 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,16 +30,22 @@
  */
 
 #include "config.h"
+#include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
+#include "sg-util.h"
 #include "sgtk-hig.h"
+#include "sgtk-message-dialog.h"
+#include "sgtk-util.h"
 #include "st-preferences-dialog.h"
 #include "st-general-tab.h"
 #include "st-network-tab.h"
+#include "st-plugins-tab.h"
 #include "st-applications-tab.h"
 #include "st-preferences-tab.h"
 #include "st-settings.h"
 #include "st-util.h"
+#include "st-main.h"
 
 /*** type definitions ********************************************************/
 
@@ -54,12 +58,14 @@ struct _STPreferencesDialogPrivate
 
 static GObjectClass *parent_class = NULL;
 
+static gboolean first_time = TRUE;
+static GSList *disabled_plugins = NULL;
+
 /*** function declarations ***************************************************/
 
 static void st_preferences_dialog_class_init	(STPreferencesDialogClass *class);
 static void st_preferences_dialog_init		(STPreferencesDialog  *dialog);
 static void st_preferences_dialog_finalize	(GObject              *object);
-static void st_preferences_dialog_unrealize	(GtkWidget	      *widget);
 
 static void st_preferences_dialog_response_h	(GtkDialog	      *dialog,
 						 int		      response,
@@ -101,22 +107,25 @@ static void
 st_preferences_dialog_class_init (STPreferencesDialogClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(class);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(class);
 
   parent_class = g_type_class_peek_parent(class);
 
   object_class->finalize = st_preferences_dialog_finalize;
-
-  widget_class->unrealize = st_preferences_dialog_unrealize;
 }
 
 static void
 st_preferences_dialog_init (STPreferencesDialog *dialog)
 {
-  GtkWidget *general_tab;
-  GtkWidget *applications_tab;
-  GtkWidget *network_tab;
+  if (first_time)
+    {
+      GSList *l;
 
+      SG_LIST_FOREACH(l, st_settings.disabled_plugins)
+	disabled_plugins = g_slist_append(disabled_plugins, g_strdup(l->data));
+
+      first_time = FALSE;
+    }
+  
   dialog->priv = g_new0(STPreferencesDialogPrivate, 1);
 
   gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
@@ -124,31 +133,24 @@ st_preferences_dialog_init (STPreferencesDialog *dialog)
 
   gtk_window_set_title(GTK_WINDOW(dialog), _("streamtuner Preferences"));
 
-  general_tab = st_general_tab_new();
-  applications_tab = st_applications_tab_new();
-  network_tab = st_network_tab_new();
-
   dialog->priv->notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(dialog->priv->notebook), GTK_POS_LEFT);
 
-  st_preferences_dialog_append_tab(dialog, general_tab);
-  st_preferences_dialog_append_tab(dialog, applications_tab);
-  st_preferences_dialog_append_tab(dialog, network_tab);
+  st_preferences_dialog_append_tab(dialog, st_general_tab_new());
+  st_preferences_dialog_append_tab(dialog, st_plugins_tab_new());
+  st_preferences_dialog_append_tab(dialog, st_applications_tab_new());
+  st_preferences_dialog_append_tab(dialog, st_network_tab_new());
 
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(dialog->priv->notebook),
-				st_settings.selected_preferences_page);
+  sg_object_link_int(G_OBJECT(dialog->priv->notebook), "page", &st_settings.selected_preferences_page);
 
   gtk_container_add(GTK_CONTAINER(SGTK_DIALOG(dialog)->contents), dialog->priv->notebook);
   gtk_widget_show(dialog->priv->notebook);
   
-  gtk_window_set_default_size(GTK_WINDOW(dialog),
-			      st_settings.preferences_window_width,
-			      st_settings.preferences_window_height);
+  sgtk_window_link_size(GTK_WINDOW(dialog),
+			&st_settings.preferences_window_width,
+			&st_settings.preferences_window_height);
 
-  g_signal_connect(G_OBJECT(dialog),
-		   "response",
-		   G_CALLBACK(st_preferences_dialog_response_h),
-		   NULL);
+  g_signal_connect(dialog, "response", G_CALLBACK(st_preferences_dialog_response_h), NULL);
 }
 
 static void
@@ -161,19 +163,6 @@ st_preferences_dialog_finalize (GObject *object)
   G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
-static void
-st_preferences_dialog_unrealize (GtkWidget *widget)
-{
-  STPreferencesDialog *dialog = ST_PREFERENCES_DIALOG(widget);
-
-  st_settings.selected_preferences_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(dialog->priv->notebook));
-  gtk_window_get_size(GTK_WINDOW(dialog),
-		      &st_settings.preferences_window_width,
-		      &st_settings.preferences_window_height);
-
-  GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
-}
-
 static void
 st_preferences_dialog_append_tab (STPreferencesDialog *dialog, GtkWidget *tab)
 {
@@ -210,7 +199,50 @@ st_preferences_dialog_response_h (GtkDialog *dialog,
 
     case GTK_RESPONSE_DELETE_EVENT:
     case GTK_RESPONSE_CLOSE:
-      gtk_widget_destroy(GTK_WIDGET(dialog));
+      {
+	GSList *l;
+	gboolean plugins_changed = FALSE;
+
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+
+	SG_LIST_FOREACH(l, disabled_plugins)
+	  if (! sg_str_slist_contains(st_settings.disabled_plugins, l->data))
+	    {
+	      plugins_changed = TRUE;
+	      break;
+	    }
+
+	if (! plugins_changed)
+	  SG_LIST_FOREACH(l, st_settings.disabled_plugins)
+	    if (! sg_str_slist_contains(disabled_plugins, l->data))
+	      {
+		plugins_changed = TRUE;
+		break;
+	      }
+
+	if (plugins_changed)
+	  {
+	    GtkWidget *dialog;
+	    int response;
+	    
+	    dialog = sgtk_message_dialog_new(st_main_get_transient(),
+					     GTK_STOCK_DIALOG_WARNING,
+					     _("Restart streamtuner?"),
+					     _("The plugins settings have changed, and streamtuner must be restarted for these changes to take effect. Would you like to restart streamtuner?"));
+
+	    gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+				   GTK_STOCK_NO, GTK_RESPONSE_NO,
+				   GTK_STOCK_YES, GTK_RESPONSE_YES,
+				   NULL);
+	    gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_YES);
+
+	    response = gtk_dialog_run(GTK_DIALOG(dialog));
+	    gtk_widget_destroy(dialog);
+	    
+	    if (response == GTK_RESPONSE_YES)
+	      st_main_restart();
+	  }
+      }
       break;
     }
 }
