@@ -1,6 +1,4 @@
 /*
- * $Id: st-search-dialog.c,v 1.13.2.5 2004/08/05 12:17:37 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,8 +30,8 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sgtk-hig.h"
 #include "st-search-dialog.h"
 #include "st-stock.h"
@@ -125,8 +123,7 @@ st_search_dialog_init (STSearchDialog *dialog)
 
   gtk_label_set_mnemonic_widget(GTK_LABEL(label), dialog->priv->entry);
 
-  g_signal_connect(G_OBJECT(dialog->priv->entry), "changed",
-		   G_CALLBACK(st_search_dialog_entry_changed_h), dialog);
+  g_signal_connect(dialog->priv->entry, "changed", G_CALLBACK(st_search_dialog_entry_changed_h), dialog);
 
   table = gtk_table_new(1, 2, FALSE);
 
