@@ -1,6 +1,4 @@
 /*
- * $Id: st-settings.h,v 1.20.2.3 2004/08/06 00:36:30 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -46,7 +44,7 @@
  *
  * The only exceptions are write-once strings (such as private_dir):
  * since there'll never be the need to reassign a value to them, they
- * can point to eitheir the stack or the heap.
+ * can point to either the stack or the heap.
  */
 typedef struct
 {
@@ -56,6 +54,7 @@ typedef struct
   const char		*cache_file;			/* write-once */
   const char		*accels_file;			/* write-once */
   const char		*splash_disabled_file;		/* write-once */
+  const char		*disabled_plugins_file;		/* write-once */
   const char		*images_dir;			/* write-once */
 
   gboolean		splash_enabled;
@@ -68,8 +67,6 @@ typedef struct
   int			toolbar_style;
   int			toolbar_size;
 
-  gboolean		save_automatic;
-
   int			main_window_width;
   int			main_window_height;
 
@@ -97,11 +94,18 @@ typedef struct
   GSList		*find_history;
   gboolean		find_case_sensitive;
   gboolean		find_wrap_around;
+
+  GSList		*disabled_plugins;
+
+  char			*music_dir;
 } STSettings;
 
 extern STSettings st_settings;
 G_LOCK_EXTERN(st_settings);
 
-void			st_settings_init     (const char *custom_private_dir);
+void st_settings_init (const char *custom_private_dir);
+
+gboolean st_settings_save_splash_enabled (GError **err);
+gboolean st_settings_save_disabled_plugins_list (GError **err);
 
 #endif /* _ST_SETTINGS_H */
