@@ -1,6 +1,4 @@
 /*
- * $Id: st-shell.c,v 1.170.2.44 2004/08/09 13:14:03 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,9 +30,10 @@
  */
 
 #include "config.h"
+#include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include "art/streamtuner.h"
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
@@ -283,8 +282,6 @@ static void st_shell_move_tab_left (STShell *shell);
 static gboolean st_shell_can_move_tab_right (STShell *shell);
 static void st_shell_move_tab_right (STShell *shell);
 
-static void st_shell_visit_homepage (STShell *shell, const char *url);
-
 static void st_shell_help (STShell *shell);
 static void st_shell_homepage (STShell *shell);
 
@@ -427,17 +424,13 @@ st_shell_make_window (STShell *shell)
   gtk_container_add(GTK_CONTAINER(shell->priv->window), shell->priv->box);
   gtk_widget_show(shell->priv->box);
 
-  gtk_window_set_default_size(GTK_WINDOW(shell->priv->window),
-			      st_settings.main_window_width,
-			      st_settings.main_window_height);
+  sgtk_window_link_size(GTK_WINDOW(shell->priv->window),
+			&st_settings.main_window_width,
+			&st_settings.main_window_height);
 
-  g_signal_connect(G_OBJECT(shell->priv->window),
-		   "window-state-event",
-		   G_CALLBACK(st_shell_window_state_event_h),
-		   shell);
-  g_signal_connect(G_OBJECT(shell->priv->window),
-		   "delete-event",
-		   G_CALLBACK(st_shell_window_delete_event_h),
+  g_object_connect(shell->priv->window,
+		   "signal::window-state-event", st_shell_window_state_event_h, shell,
+		   "signal::delete-event", st_shell_window_delete_event_h, NULL,
 		   NULL);
 }
 
@@ -483,10 +476,7 @@ st_shell_fullscreen (STShell *shell)
   gtk_container_add(GTK_CONTAINER(shell->priv->leave_fullscreen_popup), button);
   gtk_widget_show(button);
 
-  g_signal_connect(G_OBJECT(button),
-		   "clicked",
-		   G_CALLBACK(st_shell_leave_fullscreen_button_clicked_h),
-		   shell);
+  g_signal_connect(button, "clicked", G_CALLBACK(st_shell_leave_fullscreen_button_clicked_h), shell);
 
   st_shell_update_visibility(shell);
   st_shell_update_toolbar_style(shell);
@@ -496,24 +486,20 @@ st_shell_fullscreen (STShell *shell)
   gtk_widget_show(shell->priv->leave_fullscreen_popup);
 
   shell->priv->screen_size_changed_hid
-    = g_signal_connect(G_OBJECT(gdk_screen_get_default()),
+    = g_signal_connect(gdk_screen_get_default(),
 		       "size-changed",
 		       G_CALLBACK(st_shell_screen_size_changed_h),
 		       shell);
   shell->priv->key_press_event_hid
-    = g_signal_connect(G_OBJECT(shell->priv->window),
+    = g_signal_connect(shell->priv->window,
 		       "key-press-event",
 		       G_CALLBACK(st_shell_window_key_press_event_h),
 		       shell);
 
-  g_signal_connect(G_OBJECT(shell->priv->leave_fullscreen_popup),
-		   "enter-notify-event",
-		   G_CALLBACK(st_shell_leave_fullscreen_enter_notify_event_h),
-		   shell);
-  g_signal_connect(G_OBJECT(shell->priv->leave_fullscreen_popup),
-		   "leave-notify-event",
-		   G_CALLBACK(st_shell_leave_fullscreen_leave_notify_event_h),
-		   shell);
+  g_object_connect(shell->priv->leave_fullscreen_popup,
+		   "signal::enter-notify-event", st_shell_leave_fullscreen_enter_notify_event_h, shell,
+		   "signal::leave-notify-event", st_shell_leave_fullscreen_leave_notify_event_h, shell,
+		   NULL);
 
   shell->priv->leave_fullscreen_timeout_id = g_timeout_add(5000, st_shell_leave_fullscreen_timeout_cb, shell);
 }
@@ -858,7 +844,7 @@ st_shell_make_menubar (STShell *shell)
     {
       N_("/Directories/_Visit Directory Homepage"), NULL,
       st_shell_visit_directory_homepage,	0,
-      "<StockItem>",				GTK_STOCK_HOME
+      "<StockItem>",				ST_STOCK_VISIT_DIRECTORY_HOMEPAGE
     },
     {
       "/Directories/separator1",		NULL,
@@ -1046,10 +1032,7 @@ st_shell_menubar_make_directory_items (STShell *shell)
 	  g_free(accelerator);
 	}
 
-      hid = g_signal_connect(G_OBJECT(item),
-			     "toggled",
-			     G_CALLBACK(st_shell_menubar_directory_toggled_h),
-			     shell);
+      hid = g_signal_connect(item, "toggled", G_CALLBACK(st_shell_menubar_directory_toggled_h), shell);
 
       g_object_set_data(G_OBJECT(item), "handler", handler);
       g_object_set_data(G_OBJECT(item), "hid", GINT_TO_POINTER(hid));
@@ -1106,10 +1089,7 @@ st_shell_menubar_init_view_item (STShell *shell,
     gtk_widget_set_sensitive(shell->priv->view_tab_icons_item, st_settings.view_tabs);
 
   g_object_set_data(G_OBJECT(item), "shell", shell);
-  g_signal_connect(G_OBJECT(item),
-		   "toggled",
-		   G_CALLBACK(st_shell_menubar_view_toggled_h),
-		   var);
+  g_signal_connect(item, "toggled", G_CALLBACK(st_shell_menubar_view_toggled_h), var);
 }
 
 static void
@@ -1139,10 +1119,7 @@ st_shell_menubar_init_toolbar_style_item (STShell *shell,
   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), st_settings.toolbar_style == style);
 
   g_object_set_data(G_OBJECT(item), "shell", shell);
-  g_signal_connect(G_OBJECT(item),
-		   "toggled",
-		   G_CALLBACK(st_shell_menubar_toolbar_style_toggled_h),
-		   GINT_TO_POINTER(style));
+  g_signal_connect(item, "toggled", G_CALLBACK(st_shell_menubar_toolbar_style_toggled_h), GINT_TO_POINTER(style));
 }
 
 static void
@@ -1173,10 +1150,7 @@ st_shell_menubar_init_toolbar_size_item (STShell *shell,
   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), st_settings.toolbar_size == size);
 
   g_object_set_data(G_OBJECT(item), "shell", shell);
-  g_signal_connect(G_OBJECT(item),
-		   "toggled",
-		   G_CALLBACK(st_shell_menubar_toolbar_size_toggled_h),
-		   GINT_TO_POINTER(size));
+  g_signal_connect(item, "toggled", G_CALLBACK(st_shell_menubar_toolbar_size_toggled_h), GINT_TO_POINTER(size));
 }
 
 static void
@@ -1286,7 +1260,6 @@ st_shell_make_notebook (STShell *shell)
   GdkPixbuf *drag_pixbuf;
 
   shell->priv->notebook = gtk_notebook_new();
-  gtk_notebook_popup_enable(GTK_NOTEBOOK(shell->priv->notebook));
 
   /*
    * The tab labels will be moved in realtime by
@@ -1301,15 +1274,13 @@ st_shell_make_notebook (STShell *shell)
       STHandler *handler = l->data;
       GtkWidget *tab;
       GtkWidget *tab_label;
-      GtkWidget *menu_label;
       static GtkTargetEntry drag_targets[] = {
 	{ "STBrowserTabLabel", 0, 0 }
       };
       STStreamMenuItems *stream_menu_items;
 	  
       tab = st_browser_tab_new(handler);
-      tab_label = st_browser_tab_get_label(ST_BROWSER_TAB(tab), TRUE);
-      menu_label = st_browser_tab_get_label(ST_BROWSER_TAB(tab), FALSE);
+      tab_label = ST_BROWSER_TAB(tab)->label;
       
       stream_menu_items = st_stream_menu_items_new(shell, shell->priv->accel_group);
       st_stream_view_set_menu_items(ST_BROWSER_TAB(tab)->stream_view, stream_menu_items);
@@ -1326,54 +1297,34 @@ st_shell_make_notebook (STShell *shell)
 			GDK_ACTION_MOVE);
       gtk_drag_source_set_icon_pixbuf(tab_label, drag_pixbuf);
 
-      g_signal_connect(G_OBJECT(tab_label),
-		       "drag-begin",
-		       G_CALLBACK(st_shell_tab_label_drag_begin_h),
-		       shell);
-      g_signal_connect(G_OBJECT(tab_label),
-		       "drag-end",
-		       G_CALLBACK(st_shell_tab_label_drag_end_h),
-		       shell);
-      g_signal_connect(G_OBJECT(tab_label),
-		       "drag-motion",
-		       G_CALLBACK(st_shell_tab_label_drag_motion_h),
-		       shell);
-			
-      g_signal_connect(G_OBJECT(tab),
-		       "reloading-changed",
-		       G_CALLBACK(st_shell_tab_reloading_changed_h),
-		       shell);
+      g_object_connect(tab_label,
+		       "signal::drag-begin", st_shell_tab_label_drag_begin_h, shell,
+		       "signal::drag-end", st_shell_tab_label_drag_end_h, shell,
+		       "signal::drag-motion", st_shell_tab_label_drag_motion_h, shell,
+		       NULL);
+
+      g_signal_connect(tab, "reloading-changed", G_CALLBACK(st_shell_tab_reloading_changed_h), shell);
 
       if (ST_BROWSER_TAB(tab)->category_view)
-	g_signal_connect(G_OBJECT(ST_BROWSER_TAB(tab)->category_view),
+	g_signal_connect(ST_BROWSER_TAB(tab)->category_view,
 			 "selection-changed",
 			 G_CALLBACK(st_shell_category_selection_changed_h),
 			 shell);
       
-      g_signal_connect(G_OBJECT(ST_BROWSER_TAB(tab)->stream_view),
-		       "selection-changed",
-		       G_CALLBACK(st_shell_stream_selection_changed_h),
-		       shell);
-      g_signal_connect(G_OBJECT(ST_BROWSER_TAB(tab)->stream_view),
-		       "row-activated",
-		       G_CALLBACK(st_shell_stream_activated_h),
-		       shell);
+      g_object_connect(ST_BROWSER_TAB(tab)->stream_view,
+		       "signal::selection-changed", st_shell_stream_selection_changed_h, shell,
+		       "signal::row-activated", st_shell_stream_activated_h, shell,
+		       NULL);
 
       gtk_widget_show(tab);
-      gtk_widget_show(tab_label);
-      gtk_widget_show(menu_label);
-
-      gtk_notebook_append_page_menu(GTK_NOTEBOOK(shell->priv->notebook),
-				    tab,
-				    tab_label,
-				    menu_label);
 
+      gtk_notebook_append_page(GTK_NOTEBOOK(shell->priv->notebook), tab, tab_label);
       shell->priv->tabs = g_slist_append(shell->priv->tabs, tab);
     }
 
   g_object_unref(drag_pixbuf);
 
-  shell->priv->switch_page_hid = g_signal_connect_after(G_OBJECT(shell->priv->notebook),
+  shell->priv->switch_page_hid = g_signal_connect_after(shell->priv->notebook,
 							"switch-page",
 							G_CALLBACK(st_shell_switch_page_h),
 							shell);
@@ -1551,7 +1502,10 @@ st_shell_update_visibility (STShell *shell)
   g_object_set(shell->priv->toolbar, "visible", st_settings.view_toolbar, NULL);
   gtk_notebook_set_show_tabs(GTK_NOTEBOOK(shell->priv->notebook), st_settings.view_tabs);
   SG_LIST_FOREACH(l, shell->priv->tabs)
-    st_browser_tab_set_label_icon_visible(l->data, st_settings.view_tab_icons);
+    {
+      STBrowserTab *tab = l->data;
+      st_browser_tab_label_set_icon_visible(ST_BROWSER_TAB_LABEL(tab->label), st_settings.view_tab_icons);
+    }
   g_object_set(shell->priv->statusbox, "visible", st_settings.view_statusbar && ! shell->priv->fullscreen, NULL);
 }
 
@@ -1632,10 +1586,6 @@ st_shell_prepare_finalize (STShell *shell)
       g_free(st_settings.selected_handler_name);
       st_settings.selected_handler_name = g_strdup(st_handler_get_name(selected_tab->handler));
     }
-  
-  gtk_window_get_size(GTK_WINDOW(shell->priv->window),
-		      &st_settings.main_window_width,
-		      &st_settings.main_window_height);
 }
 
 void
@@ -1761,8 +1711,7 @@ st_shell_can_reload (STShell *shell)
 
   selected_tab = st_shell_get_selected_tab(shell);
 
-  return selected_tab
-    && ST_HANDLER_EVENT_HAS_RELOAD(selected_tab->handler);
+  return selected_tab && st_browser_tab_can_reload(selected_tab);
 }
 
 static void
@@ -1836,14 +1785,10 @@ st_shell_find (STShell *shell)
       sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
       sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
       
-      g_signal_connect(G_OBJECT(shell->priv->find),
-		       "notify",
-		       G_CALLBACK(st_shell_find_notify_h),
+      g_object_connect(shell->priv->find,
+		       "signal::notify", st_shell_find_notify_h, NULL,
+		       "signal::response", st_shell_find_response_h, shell,
 		       NULL);
-      g_signal_connect(G_OBJECT(shell->priv->find),
-		       "response",
-		       G_CALLBACK(st_shell_find_response_h),
-		       shell);
 
       gtk_widget_show(shell->priv->find);
     }
@@ -2162,7 +2107,7 @@ st_shell_present_stream_properties (STShell *shell)
       shell->priv->stream_properties = st_stream_properties_dialog_new(shell);
       g_object_add_weak_pointer(G_OBJECT(shell->priv->stream_properties), (gpointer *) &shell->priv->stream_properties);
 
-      g_signal_connect(G_OBJECT(shell->priv->stream_properties),
+      g_signal_connect(shell->priv->stream_properties,
 		       "response",
 		       G_CALLBACK(st_shell_stream_properties_response_h),
 		       shell);
@@ -2237,7 +2182,7 @@ st_shell_present_about (STShell *shell)
       shell->priv->about = st_about_dialog_new(GTK_WINDOW(shell->priv->window));
       g_object_add_weak_pointer(G_OBJECT(shell->priv->about), (gpointer *) &shell->priv->about);
 
-      g_signal_connect(G_OBJECT(shell->priv->about),
+      g_signal_connect(shell->priv->about,
 		       "response",
 		       G_CALLBACK(st_shell_dialog_response_h),
 		       NULL);
@@ -2261,7 +2206,7 @@ st_shell_can_visit_directory_homepage (STShell *shell)
 
   selected_tab = st_shell_get_selected_tab(shell);
 
-  return selected_tab && st_handler_get_home(selected_tab->handler);
+  return selected_tab && st_browser_tab_can_visit_homepage(selected_tab);
 }
 
 static void
@@ -2273,7 +2218,7 @@ st_shell_visit_directory_homepage (STShell *shell)
   g_return_if_fail(st_shell_can_visit_directory_homepage(shell));
 
   selected_tab = st_shell_get_selected_tab(shell);
-  st_shell_visit_homepage(shell, st_handler_get_home(selected_tab->handler));
+  st_browser_tab_visit_homepage(selected_tab);
 }
 
 gboolean
@@ -2558,27 +2503,6 @@ st_shell_move_tab_right (STShell *shell)
   st_shell_move_tab(shell, +1);
 }
 
-static void
-st_shell_visit_homepage (STShell *shell, const char *url)
-{
-  GError *err = NULL;
-
-  g_return_if_fail(ST_IS_SHELL(shell));
-  g_return_if_fail(url != NULL);
-
-  if (! st_action_run("view-web", url, &err))
-    {
-      char *normalized;
-
-      normalized = st_dialog_normalize(err->message);
-
-      st_error_dialog(_("Unable to visit the homepage"), "%s", normalized);
-
-      g_free(normalized);
-      g_error_free(err);
-    }
-}
-
 static void
 st_shell_help (STShell *shell)
 {
@@ -2590,7 +2514,7 @@ st_shell_homepage (STShell *shell)
 {
   g_return_if_fail(ST_IS_SHELL(shell));
 
-  st_shell_visit_homepage(shell, ST_HOME);
+  st_visit_homepage(ST_HOME);
 }
 
 void
