@@ -1,6 +1,4 @@
 /*
- * $Id: st-stock.c,v 1.35.2.8 2004/08/06 18:53:54 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,6 +30,7 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include "art/tune_in.h"
@@ -40,7 +39,6 @@
 #include "art/search.h"
 #include "art/category.h"
 #include "art/category_open.h"
-#include "gettext.h"
 #include "sgtk-stock.h"
 #include "st-stock.h"
 
@@ -57,6 +55,7 @@ static const GtkStockItem items[] = {
   { ST_STOCK_NEW_PRESELECTION, N_("_New Preselection"), 0, 0, NULL },
   { ST_STOCK_ADD_BOOKMARK, N_("_Add Bookmark"), 0, 0, NULL },
   { ST_STOCK_LEAVE_FULLSCREEN, N_("Leave Fullscreen"), 0, 0, NULL },
+  { ST_STOCK_VISIT_DIRECTORY_HOMEPAGE, N_("_Visit Directory Homepage"), 0, 0, NULL }
 };
 
 /*** implementation **********************************************************/
@@ -79,6 +78,7 @@ st_stock_init (void)
     SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_CATEGORY_OPEN, art_category_open),
     SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_LEAVE_FULLSCREEN, GTK_STOCK_QUIT),
     SGTK_STOCK_ICON_FROM_THEME(ST_STOCK_SELECT_ALL, "stock_select-all"),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_VISIT_DIRECTORY_HOMEPAGE, GTK_STOCK_HOME),
     SGTK_STOCK_ICON_END
   };
       
