@@ -1,6 +1,4 @@
 /*
- * $Id: st-stream-properties-dialog.c,v 1.86.2.4 2004/08/05 13:48:27 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,8 +31,8 @@
 
 #include "config.h"
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-util.h"
 #include "st-stream-properties-dialog.h"
 #include "st-handler.h"
@@ -57,7 +55,6 @@ struct _STStreamPropertiesDialogPrivate
   STShell		*shell;
 
   STStreamBag		*stream_bag;
-  unsigned int		changed_hid;
 
   GtkWidget		*previous_button;
   GtkWidget		*next_button;
@@ -85,9 +82,9 @@ static GObjectClass *parent_class = NULL;
 
 static void st_stream_properties_dialog_class_init	(STStreamPropertiesDialogClass *class);
 static void st_stream_properties_dialog_init		(STStreamPropertiesDialog *dialog);
-static void st_stream_properties_dialog_unrealize	(GtkWidget *widget);
 static void st_stream_properties_dialog_finalize	(GObject *object);
 
+static void st_stream_properties_dialog_unset_stream	(STStreamPropertiesDialog *dialog);
 static void st_stream_properties_dialog_construct_table	(STStreamPropertiesDialog *dialog);
 static void st_stream_properties_dialog_update_title	(STStreamPropertiesDialog *dialog);
 static void st_stream_properties_dialog_update_data	(STStreamPropertiesDialog *dialog);
@@ -112,6 +109,8 @@ static void st_stream_properties_dialog_cancel_list_free (STStreamPropertiesDial
 
 static void st_stream_properties_dialog_stream_changed_h (STStreamBag *bag,
 							  gpointer user_data);
+static void st_stream_properties_dialog_stream_deleted_h (STStreamBag *bag,
+							  gpointer user_data);
 
 /*** implementation **********************************************************/
 
@@ -147,13 +146,10 @@ static void
 st_stream_properties_dialog_class_init (STStreamPropertiesDialogClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(class);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(class);
 
   parent_class = g_type_class_peek_parent(class);
 
   object_class->finalize = st_stream_properties_dialog_finalize;
-
-  widget_class->unrealize = st_stream_properties_dialog_unrealize;
 }
 
 static void
@@ -167,22 +163,9 @@ st_stream_properties_dialog_init (STStreamPropertiesDialog *dialog)
   gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   dialog->priv->ok_button = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
 
-  gtk_window_set_default_size(GTK_WINDOW(dialog),
-			      st_settings.stream_properties_window_width,
-			      -1);
-}
-
-static void
-st_stream_properties_dialog_unrealize (GtkWidget *widget)
-{
-  GtkWindow *window = GTK_WINDOW(widget);
-  int height;			/* dummy */
-
-  gtk_window_get_size(window,
-		      &st_settings.stream_properties_window_width,
-		      &height);
-
-  GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
+  sgtk_window_link_size(GTK_WINDOW(dialog),
+			&st_settings.stream_properties_window_width,
+			NULL);
 }
 
 static void
@@ -190,12 +173,7 @@ st_stream_properties_dialog_finalize (GObject *object)
 {
   STStreamPropertiesDialog *dialog = ST_STREAM_PROPERTIES_DIALOG(object);
 
-  if (dialog->priv->stream_bag)
-    {
-      g_signal_handler_disconnect(dialog->priv->stream_bag, dialog->priv->changed_hid);
-      g_object_unref(dialog->priv->stream_bag);
-    }
-
+  st_stream_properties_dialog_unset_stream(dialog);
   g_slist_free(dialog->priv->widgets);
   st_stream_properties_dialog_cancel_list_free(dialog);
   g_free(dialog->priv);
@@ -203,6 +181,21 @@ st_stream_properties_dialog_finalize (GObject *object)
   G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
+static void
+st_stream_properties_dialog_unset_stream (STStreamPropertiesDialog *dialog)
+{
+  g_return_if_fail(ST_IS_STREAM_PROPERTIES_DIALOG(dialog));
+
+  if (dialog->priv->stream_bag)
+    {
+      g_object_disconnect(dialog->priv->stream_bag,
+			  "any-signal", st_stream_properties_dialog_stream_changed_h, dialog,
+			  "any-signal", st_stream_properties_dialog_stream_deleted_h, dialog,
+			  NULL);
+      g_object_unref(dialog->priv->stream_bag);
+    }
+}
+
 static void
 st_stream_properties_dialog_construct_table (STStreamPropertiesDialog *dialog)
 {
@@ -491,11 +484,7 @@ st_stream_properties_dialog_set_stream (STStreamPropertiesDialog *dialog,
   g_return_if_fail(ST_IS_STREAM_PROPERTIES_DIALOG(dialog));
   g_return_if_fail(ST_IS_STREAM_BAG(stream_bag));
 
-  if (dialog->priv->stream_bag)
-    {
-      g_signal_handler_disconnect(dialog->priv->stream_bag, dialog->priv->changed_hid);
-      g_object_unref(dialog->priv->stream_bag);
-    }
+  st_stream_properties_dialog_unset_stream(dialog);
 
   g_object_ref(stream_bag);
   if (stream_bag->handler != dialog->priv->table_handler)
@@ -505,10 +494,11 @@ st_stream_properties_dialog_set_stream (STStreamPropertiesDialog *dialog,
     }
 
   dialog->priv->stream_bag = stream_bag;
-  dialog->priv->changed_hid = g_signal_connect(G_OBJECT(dialog->priv->stream_bag),
-					       "changed",
-					       G_CALLBACK(st_stream_properties_dialog_stream_changed_h),
-					       dialog);
+
+  g_object_connect(dialog->priv->stream_bag,
+		   "signal::changed", st_stream_properties_dialog_stream_changed_h, dialog,
+		   "signal::deleted", st_stream_properties_dialog_stream_deleted_h, dialog,
+		   NULL);
 
   st_stream_properties_dialog_update_title(dialog);
   st_stream_properties_dialog_update_data(dialog);
@@ -524,6 +514,15 @@ st_stream_properties_dialog_stream_changed_h (STStreamBag *bag,
   st_stream_properties_dialog_update_data(dialog);
 }
 
+static void
+st_stream_properties_dialog_stream_deleted_h (STStreamBag *bag,
+					      gpointer user_data)
+{
+  STStreamPropertiesDialog *dialog = user_data;
+
+  gtk_dialog_response(GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);
+}
+
 void
 st_stream_properties_dialog_update_sensitivity (STStreamPropertiesDialog *dialog)
 {
@@ -607,10 +606,7 @@ st_stream_properties_dialog_optimize_fields_and_values (STStreamBag *stream_bag,
   g_return_if_fail(fields != NULL);
   g_return_if_fail(values != NULL);
   
-  f = *fields;
-  v = *values;
-
-  while (f && v)
+  for (f = *fields, v = *values; f && v; f = f->next, v = v->next)
     {
       STHandlerField *field = f->data;
       GValue *value = v->data;
@@ -630,9 +626,6 @@ st_stream_properties_dialog_optimize_fields_and_values (STStreamBag *stream_bag,
 	}
 
       g_value_unset(&current_value);
-
-      f = f->next;
-      v = v->next;
     }
 
   g_slist_free(*fields);
