@@ -1,6 +1,4 @@
 /*
- * $Id: st-stream-task.c,v 1.10.2.3 2004/08/05 12:46:36 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,7 +30,7 @@
  */
 
 #include "config.h"
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "sg-util.h"
 #include "st-dialog-api.h"
 #include "st-shell.h"
