@@ -1,6 +1,4 @@
 /*
- * $Id: st-stream-view.c,v 1.132.2.10 2004/08/09 12:49:56 jylefort Exp $
- *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,9 +31,8 @@
 
 #include "config.h"
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include "gettext.h"
-#include "sgtk-handlers.h"
 #include "sg-util.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
@@ -77,7 +74,6 @@ static unsigned int stream_view_signals[LAST_SIGNAL] = { 0 };
 static void st_stream_view_init		(STStreamView		*view);
 static void st_stream_view_class_init	(STStreamViewClass	*class);
 static void st_stream_view_finalize	(GObject		*object);
-static void st_stream_view_unrealize	(GtkWidget		*widget);
 
 static GObject *st_stream_view_constructor (GType type,
 					    unsigned int n_construct_properties,
@@ -99,6 +95,9 @@ static void st_stream_view_construct_column_menu  (STStreamView       *view,
 
 static void st_stream_view_column_visible_toggled_h (GtkCheckMenuItem *item,
 						     gpointer	      data);
+static void st_stream_view_column_notify_width_h	(GObject      *object,
+							 GParamSpec   *pspec,
+							 gpointer     data);
 static void st_stream_view_column_hide_activate_h	(GtkMenuItem  *item,
 							 gpointer     data);
 static void st_stream_view_column_show_all_activate_h	(GtkMenuItem  *item,
@@ -143,7 +142,6 @@ static void
 st_stream_view_class_init (STStreamViewClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(class);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(class);
 
   parent_class = g_type_class_peek_parent(class);
 
@@ -151,8 +149,6 @@ st_stream_view_class_init (STStreamViewClass *class)
   object_class->constructor = st_stream_view_constructor;
   object_class->set_property = st_stream_view_set_property;
 
-  widget_class->unrealize = st_stream_view_unrealize;
-
   g_object_class_install_property(object_class,
 				  PROP_HANDLER,
 				  g_param_spec_pointer("handler",
@@ -192,23 +188,6 @@ st_stream_view_finalize (GObject *object)
   G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
-static void
-st_stream_view_unrealize (GtkWidget *widget)
-{
-  STStreamView *view = ST_STREAM_VIEW(widget);
-  GtkTreeViewColumn *column;
-  int i = N_VISIBLE_STOCK_COLUMNS;
-
-  /* save the column widths */
-  while ((column = gtk_tree_view_get_column(GTK_TREE_VIEW(view), i++)))
-    {
-      STHandlerField *field = g_object_get_data(G_OBJECT(column), "field");
-      st_handler_field_set_width(field, gtk_tree_view_column_get_width(column));
-    }
-
-  GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
-}
-
 static GObject *
 st_stream_view_constructor (GType type,
 			    unsigned int n_construct_properties,
@@ -232,7 +211,7 @@ st_stream_view_constructor (GType type,
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
 
   gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
-  g_signal_connect(G_OBJECT(selection),
+  g_signal_connect(selection,
 		   "changed",
 		   G_CALLBACK(st_stream_view_selection_changed_h),
 		   view);
@@ -292,7 +271,7 @@ st_stream_view_construct_columns_menu (STStreamView *view)
 
       gtk_menu_shell_append(GTK_MENU_SHELL(view->columns_menu), item);
 
-      hid = g_signal_connect(G_OBJECT(item),
+      hid = g_signal_connect(item,
 			     "toggled",
 			     G_CALLBACK(st_stream_view_column_visible_toggled_h),
 			     NULL);
@@ -388,6 +367,11 @@ st_stream_view_construct_columns (STStreamView *view)
       
 	      gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
 	      st_stream_view_construct_column_menu(view, column);
+
+	      g_signal_connect(column,
+			       "notify::width",
+			       G_CALLBACK(st_stream_view_column_notify_width_h),
+			       NULL);
 	    }
 	  else
 	    pending_fields = g_slist_append(pending_fields, field);
@@ -470,23 +454,25 @@ st_stream_view_construct_column_menu (STStreamView *view,
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), separator);
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), show_all);
 
-  g_signal_connect(G_OBJECT(hide),
+  g_signal_connect(hide,
 		   "activate",
 		   G_CALLBACK(st_stream_view_column_hide_activate_h),
 		   column);
-  g_signal_connect(G_OBJECT(show_all),
+  g_signal_connect(show_all,
 		   "activate",
 		   G_CALLBACK(st_stream_view_column_show_all_activate_h),
 		   view);
 
-  g_signal_connect_swapped(G_OBJECT(column->button),
-			   "popup-menu",
-			   G_CALLBACK(sgtk_popup_menu_h),
-			   G_OBJECT(menu));
-  g_signal_connect_swapped(G_OBJECT(column->button),
-			   "button-press-event",
-			   G_CALLBACK(sgtk_popup_menu_mouse_h),
-			   G_OBJECT(menu));
+  sgtk_widget_set_popup_menu(column->button, GTK_MENU(menu));
+}
+
+static void
+st_stream_view_column_notify_width_h (GObject *object,
+				      GParamSpec *pspec,
+				      gpointer data)
+{
+  STHandlerField *field = g_object_get_data(object, "field");
+  st_handler_field_set_width(field, gtk_tree_view_column_get_width(GTK_TREE_VIEW_COLUMN(object)));
 }
 
 static void
@@ -723,14 +709,7 @@ st_stream_view_set_menu_items (STStreamView *view, STStreamMenuItems *items)
   menu = gtk_menu_new();
   st_stream_menu_items_insert_into_shell(view->priv->menu_items, GTK_MENU_SHELL(menu), 0);
 
-  g_signal_connect_swapped(G_OBJECT(view),
-			   "popup-menu",
-			   G_CALLBACK(sgtk_popup_menu_h),
-			   G_OBJECT(menu));
-  g_signal_connect_swapped(G_OBJECT(view),
-			   "button_press_event",
-			   G_CALLBACK(sgtk_popup_menu_mouse_h),
-			   G_OBJECT(menu));
+  sgtk_widget_set_popup_menu(GTK_WIDGET(view), GTK_MENU(menu));
 }
 
 void
@@ -792,7 +771,7 @@ st_stream_view_has_selected_streams (STStreamView *view)
   GSList *selected_streams;
   gboolean has;
 
-  g_return_val_if_fail(ST_IS_STREAM_VIEW(view), NULL);
+  g_return_val_if_fail(ST_IS_STREAM_VIEW(view), FALSE);
 
   selected_streams = st_stream_view_get_selected_streams(view);
   has = selected_streams != NULL;
