@@ -1,6 +1,4 @@
 /*
- * $Id: st-thread.c,v 1.33.2.4 2004/08/05 12:46:36 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -35,7 +33,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <glib.h>
-#include "gettext.h"
+#include <glib/gi18n.h>
 #include "st-dialog-api.h"
 #include "st-thread.h"
 #include "st-handler.h"
