@@ -1,6 +1,4 @@
 /*
- * $Id: st-thread.h,v 1.20 2004/03/25 14:43:59 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -66,7 +64,7 @@ void		st_thread_run			(STThread	*thread);
 STThread	*st_thread_get			(void);
 void		st_thread_printf		(STThread	*thread,
 						 const char	*format,
-						 ...);
+						 ...) G_GNUC_PRINTF(2, 3);
 void		st_thread_set_progress		(STThread	*thread,
 						 double		fraction);
 void		st_thread_forget		(STThread	*thread);
