@@ -1,6 +1,4 @@
 /*
- * $Id: st-transfer.c,v 1.73.2.9 2004/08/05 13:19:28 jylefort Exp $
- *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -33,10 +31,11 @@
 
 #include "config.h"
 #include <string.h>
+#include <stdlib.h>
 #include <curl/curl.h>
 #ifndef ST_REGRESSION_TEST
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "st-dialog-api.h"
@@ -877,6 +876,6 @@ st_transfer_init (void)
       st_error_dialog(_("A fatal error has occurred"),
 		      _("Unable to initialize the curl library."));
       exit(1);
-#endif ST_REGRESSION_TEST
+#endif /* ST_REGRESSION_TEST */
     }
 }
