@@ -1,6 +1,4 @@
 /*
- * $Id: st-util.c,v 1.2.2.3 2004/08/05 12:46:36 jylefort Exp $
- *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
  *
@@ -32,34 +30,102 @@
  */
 
 #include "config.h"
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "art/streamtuner_logo.h"
-#include "gettext.h"
+#include "art/logo.h"
 #include "st-action.h"
 #include "st-dialog-api.h"
 
+/*** API implementation ******************************************************/
+
+char *
+st_format_bitrate (int bitrate)
+{
+  g_return_val_if_fail(bitrate > 0, NULL);
+  return g_strdup_printf(_("%i kbps"), bitrate);
+}
+
+char *
+st_format_samplerate (int samplerate)
+{
+  g_return_val_if_fail(samplerate > 0, NULL);
+  return g_strdup_printf(_("%i Hz"), samplerate);
+}
+
+char *
+st_format_channels (int channels)
+{
+  g_return_val_if_fail(channels > 0, NULL);
+  switch (channels)
+    {
+    case 1:	return g_strdup(_("Mono"));
+    case 2:	return g_strdup(_("Stereo"));
+    default:	return g_strdup_printf(ngettext("%i channel", "%i channels", channels), channels);
+    }
+}
+
+char *
+st_format_audio_properties (int bitrate,
+			    int samplerate,
+			    int channels)
+{
+  GString *audio;
+  char *str;
+
+  audio = g_string_new(NULL);
+
+  if (bitrate > 0)
+    {
+      str = st_format_bitrate(bitrate);
+      g_string_append(audio, str);
+      g_free(str);
+    }
+  
+  if (samplerate > 0)
+    {
+      if (*audio->str)
+	g_string_append(audio, ", ");
+
+      str = st_format_samplerate(samplerate);
+      g_string_append(audio, str);
+      g_free(str);
+    }
+  
+  if (channels > 0)
+    {
+      if (*audio->str)
+	g_string_append(audio, ", ");
+
+      str = st_format_channels(channels);
+      g_string_append(audio, str);
+      g_free(str);
+    }
+
+  if (*audio->str)
+    return g_string_free(audio, FALSE);
+  else
+    {
+      g_string_free(audio, TRUE);
+      return NULL;
+    }
+}
+
+/*** private implementation **************************************************/
+
 GtkWidget *
 st_logo_new (void)
 {
-  GtkWidget *image;
-  GtkWidget *event_box;
   GdkPixbuf *logo;
-  GdkColor bg = { 0, 0xFFFF, 0xF000, 0x0000 };
+  GtkWidget *image;
 
-  logo = gdk_pixbuf_new_from_inline(sizeof(art_streamtuner_logo),
-				    art_streamtuner_logo,
+  logo = gdk_pixbuf_new_from_inline(sizeof(art_logo),
+				    art_logo,
 				    FALSE,
 				    NULL);
   image = gtk_image_new_from_pixbuf(logo);
   g_object_unref(logo);
 
-  event_box = gtk_event_box_new();
-  gtk_widget_modify_bg(event_box, GTK_STATE_NORMAL, &bg);
-  gtk_container_add(GTK_CONTAINER(event_box), image);
-
-  gtk_widget_show(image);
-
-  return event_box;
+  return image;
 }
 
 void
@@ -99,3 +165,23 @@ st_show_help (const char *link_id)
   
   g_free(filename);
 }
+
+void
+st_visit_homepage (const char *url)
+{
+  GError *err = NULL;
+
+  g_return_if_fail(url != NULL);
+
+  if (! st_action_run("view-web", url, &err))
+    {
+      char *normalized;
+
+      normalized = st_dialog_normalize(err->message);
+
+      st_error_dialog(_("Unable to visit the homepage"), "%s", normalized);
+
+      g_free(normalized);
+      g_error_free(err);
+    }
+}
